===============================
Bingo
===============================

.. image:: https://badge.fury.io/py/bingo.png
    :target: http://badge.fury.io/py/bingo
    
.. image:: https://travis-ci.org/oscarolar/bingo.png?branch=master
        :target: https://travis-ci.org/oscarolar/bingo

.. image:: https://pypip.in/d/bingo/badge.png
        :target: https://crate.io/packages/bingo?version=latest


Bingo is

* Free software: BSD license
* Documentation: http://bingo.rtfd.org.

Features
--------

* TODO